@@ -39,7 +39,6 @@ class DataSet:
                 Path to the sav file we want to use as our data.
         """
         # this is okay because the path format will be the same as the OS running this
-        filename = os.path.basename(file_path)
 
         with open(file_path, mode='rb') as file:
             fileContent = file.read()
@@ -67,6 +66,19 @@ class DataSet:
         self.qp_data = result['csv']
         self.dataset_type = 'quantipy'
 
+    def use_nebu(self, nebu_url):
+        payload = {
+            'datasource': {
+                'type' : 'Nebu',
+                'nebu_url' : nebu_url
+            }
+        }
+        response = self.tally.post_request('tally', 'convert_data_to_csv_json', payload)
+        result = json.loads(response.content)
+        self.qp_meta = json.dumps(result['json'])
+        self.qp_data = result['csv']
+        self.dataset_type = 'quantipy'
+
     def use_confirmit(self, source_projectid, source_idp_url, source_client_id, source_client_secret, source_public_url):
         payload = {
             'datasource': {
@@ -84,6 +96,27 @@ class DataSet:
         self.qp_data = result['csv']
         self.dataset_type = 'quantipy'
 
+    def use_unicom(self, mdd_filename, ddf_filename):
+        with open(mdd_filename, mode='rb') as file:
+            fileContent_mdd = file.read()
+
+        with open(ddf_filename, mode='rb') as file:
+            fileContent_ddf = file.read()
+        
+        payload={}
+
+        files=[ 
+            ('mdd',(mdd_filename,io.BytesIO(fileContent_mdd),'text/xml')),
+            ('ddf', (ddf_filename,io.BytesIO(fileContent_ddf), 'application/x-sqlite3')) 
+        ]
+        response = self.tally.post_request('tally', 'convert_data_to_csv_json', payload, files)
+        result = json.loads(response.content)
+        self.qp_meta = json.dumps(result['json'])
+        self.qp_data = result['csv']
+        self.dataset_type = 'quantipy'
+
+    def get_dataframe(self):
+        return pd.read_csv(io.StringIO(self.qp_data))
 
     def prepare_post_params(self, data_params, params={}):
         # initialise the payload with our chosen data
@@ -109,6 +142,46 @@ class DataSet:
             print(response.content)
             raise ValueError(response.content)
 
+    @add_data
+    def variables(self, data_params=None):
+        files, payload = self.prepare_post_params(data_params)
+        response = self.tally.post_request('tally', 'variables', payload, files)
+        json_dict = json.loads(response.content)
+        return json_dict
+
+    @add_data
+    def meta(self, data_params=None, **kwargs):
+        files, payload = self.prepare_post_params(data_params, kwargs)
+        response = self.tally.post_request('tally', 'meta', payload, files)
+        json_dict = json.loads(response.content)
+        return Tally.result_to_dataframe(json_dict)
+
+    @add_data
+    def derive(self, data_params=None, **kwargs):
+        files, payload = self.prepare_post_params(data_params, kwargs)
+        response = self.tally.post_request('tally', 'derive', payload, files)
+        json_dict = json.loads(response.content)
+        self.add_column_to_data(kwargs['name'], json_dict['data'], json_dict['meta'])
+        return json_dict
+
+    @add_data
+    def weight(self, data_params=None, **kwargs):
+        files, payload = self.prepare_post_params(data_params, kwargs)
+        response = self.tally.post_request('tally', 'weight', payload, files)
+        json_dict = json.loads(response.content)
+        self.add_column_to_data(kwargs['variable'], json_dict['weight_data'], json_dict['weight_var_meta'])
+        return json_dict
+
+    def add_column_to_data(self, name, data, new_meta):
+        df = pd.read_csv(io.StringIO(self.qp_data))
+        new_series = pd.Series(data)
+        new_series.index = [int(i) for i in new_series.index]
+        df[name] = new_series
+        meta = json.loads(self.qp_meta)
+        meta['columns'][name] = new_meta
+        self.qp_meta = json.dumps(meta)
+        self.qp_data = df.to_csv()
+
     @add_data
     def convert_spss_to_csv_json(self, data_params=None):
         files, payload = self.prepare_post_params(data_params)
